@@ -3,8 +3,8 @@ use clap::{
 	ArgEnum,
 	Parser,
 };
-use git_cliff_core::glob::Pattern;
 use git_cliff_core::DEFAULT_CONFIG;
+use glob::Pattern;
 use std::path::PathBuf;
 
 #[derive(Debug, Clone, Copy, ArgEnum)]
@@ -107,7 +107,7 @@ pub struct Opt {
 	#[clap(short, long, help_heading = Some("FLAGS"))]
 	pub unreleased:   bool,
 	/// Sorts the tags chronologically.
-	#[clap(long, help_heading = Some("FLAGS"))]
+	#[clap(short, long, help_heading = Some("FLAGS"))]
 	pub date_order:   bool,
 	/// Prints changelog context as JSON.
 	#[clap(long, help_heading = Some("FLAGS"))]
